==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/interceptors/inheritance/InterceptorIncludedByIndirect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.interceptors.inheritance;

import javax.enterprise.context.Dependent;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;

@Dependent
@Interceptor
@BindingIncludedByIndirect
public class InterceptorIncludedByIndirect
{
    private String nonProxyName;

    public InterceptorIncludedByIndirect()
    {
        super();
        nonProxyName = "InterceptorIncludedByIndirect";
    }

    @AroundInvoke
    public Object myint(InvocationContext ic) throws Exception
    {
        if (ic.getMethod().getName().equals("shuffle"))
        {
            DeckType d = (DeckType) ic.getTarget();
            d.setIntercepted(nonProxyName);
        }
        return ic.proceed();
    }

}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/interceptors/inheritance/InterceptorIncludedByIndirect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.interceptors.inheritance;

import jakarta.enterprise.context.Dependent;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.Interceptor;
import jakarta.interceptor.InvocationContext;

@Dependent
@Interceptor
@BindingIncludedByIndirect
public class InterceptorIncludedByIndirect
{
    private String nonProxyName;

    public InterceptorIncludedByIndirect()
    {
        super();
        nonProxyName = "InterceptorIncludedByIndirect";
    }

    @AroundInvoke
    public Object myint(InvocationContext ic) throws Exception
    {
        if (ic.getMethod().getName().equals("shuffle"))
        {
            DeckType d = (DeckType) ic.getTarget();
            d.setIntercepted(nonProxyName);
        }
        return ic.proceed();
    }

}
